@@ -413,9 +413,10 @@ selShortTileProc(tile, ssd)
     Tile *tile;
     ShortSearchData *ssd;
 {
-    if ((int)CD2INT(tile->ti_client) < ssd->cost)
+    const int curr = (int)TiGetClientINT(tile);
+    if (curr < ssd->cost)
     {
-	ssd->cost = (int)CD2INT(tile->ti_client);
+	ssd->cost = curr;
 	ssd->tile = tile;
     }
     return 0;
@@ -457,7 +458,7 @@ selShortFindReverse(rlist, tile, pnum, fdir)
     TileType ttype;
 
     mindir = fdir;
-    mincost = (int)CD2INT(tile->ti_client);
+    mincost = (int)TiGetClientINT(tile);
 
     while (TRUE)
     {
@@ -504,7 +505,7 @@ selShortFindReverse(rlist, tile, pnum, fdir)
 	newrrec->r_next = *rlist;
 	*rlist = newrrec;
 
-	if ((int)CD2INT(tile->ti_client) == 0) return 0;	/* We're done */
+	if ((int)TiGetClientINT(tile) == 0) return 0;	/* We're done */
 
 	minp = pnum;
 
@@ -518,10 +519,12 @@ selShortFindReverse(rlist, tile, pnum, fdir)
 
 	for (tp = RT(tile); RIGHT(tp) > LEFT(tile); tp = BL(tp))
 	{
-	    if (tp->ti_client == (ClientData)CLIENTDEFAULT) continue;
-	    if ((int)CD2INT(tp->ti_client) < mincost)
+	    const ClientData ticlient = TiGetClient(tp);
+	    if (ticlient == CLIENTDEFAULT) continue;
+	    const int curr = (int)CD2INT(ticlient);
+	    if (curr < mincost)
 	    {
-		mincost = (int)CD2INT(tp->ti_client);
+		mincost = curr;
 		mintp = tp;
 		mindir = GEO_NORTH;
 	    }
@@ -538,10 +541,12 @@ leftside:
 
 	for (tp = BL(tile); BOTTOM(tp) < TOP(tile); tp = RT(tp))
 	{
-	    if (tp->ti_client == (ClientData)CLIENTDEFAULT) continue;
-	    if ((int)CD2INT(tp->ti_client) < mincost)
+	    const ClientData ticlient = TiGetClient(tp);
+	    if (ticlient == CLIENTDEFAULT) continue;
+	    const int curr = (int)CD2INT(ticlient);
+	    if (curr < mincost)
 	    {
-		mincost = (int)CD2INT(tp->ti_client);
+		mincost = curr;
 		mintp = tp;
 		mindir = GEO_WEST;
 	    }
@@ -558,10 +563,12 @@ bottomside:
 
 	for (tp = LB(tile); LEFT(tp) < RIGHT(tile); tp = TR(tp))
 	{
-	    if (tp->ti_client == (ClientData)CLIENTDEFAULT) continue;
-	    if ((int)CD2INT(tp->ti_client) < mincost)
+	    const ClientData ticlient = TiGetClient(tp);
+	    if (ticlient == CLIENTDEFAULT) continue;
+	    const int curr = (int)CD2INT(ticlient);
+	    if (curr < mincost)
 	    {
-		mincost = (int)CD2INT(tp->ti_client);
+		mincost = curr;
 		mintp = tp;
 		mindir = GEO_SOUTH;
 	    }
@@ -578,10 +585,12 @@ rightside:
 
 	for (tp = TR(tile); TOP(tp) > BOTTOM(tile); tp = LB(tp))
 	{
-	    if (tp->ti_client == (ClientData)CLIENTDEFAULT) continue;
-	    if ((int)CD2INT(tp->ti_client) < mincost)
+	    const ClientData ticlient = TiGetClient(tp);
+	    if (ticlient == CLIENTDEFAULT) continue;
+	    const int curr = (int)CD2INT(ticlient);
+	    if (curr < mincost)
 	    {
-		mincost = (int)CD2INT(tp->ti_client);
+		mincost = curr;
 		mintp = tp;
 		mindir = GEO_EAST;
 	    }
@@ -620,7 +629,7 @@ donesides:
 	if (mincost == INT_MAX) return 1;
 
 	/* Failsafe:  Avoid infinite recursion */
-	if ((tile == mintp) || (tile->ti_client == CLIENTDEFAULT))
+	if ((tile == mintp) || (TiGetClient(tile) == CLIENTDEFAULT))
 	{
 	    TxError("Failed to trace back shorting path.\n");
 	    break;
@@ -712,7 +721,7 @@ selShortProcessTile(tile, cost, fdir, mask)
     /* algorithm to find any valid path but not the best path.   That	*/
     /* choice keeps the algorithm fast and efficient.			*/
 
-    if (tile->ti_client != (ClientData)CLIENTDEFAULT) return 1;
+    if (TiGetClient(tile) != CLIENTDEFAULT) return 1;
 
     if (IsSplit(tile))
     {
@@ -748,10 +757,12 @@ selShortProcessTile(tile, cost, fdir, mask)
     /* If this tile is unvisited, or has a lower cost, then return and	  */
     /* keep going.  Otherwise, return 1 to stop the search this direction */
 
-    if (tile->ti_client == (ClientData)CLIENTDEFAULT)
-	TiSetClient(tile, cost);
-    else if ((int)CD2INT(tile->ti_client) > cost)
-	TiSetClient(tile, cost);
+    const ClientData ticlient = TiGetClient(tile);
+    const int curr = (int)CD2INT(ticlient);
+    if (ticlient == CLIENTDEFAULT)
+	TiSetClientINT(tile, cost);
+    else if (curr > cost)
+	TiSetClientINT(tile, cost);
     else
 	return 1;
 
@@ -795,7 +806,7 @@ selShortFindForward(srctile, srctype, srcpnum, desttile)
 	ShortStack = StackNew(64);
 
     /* Set the cost of the source tile to zero */
-    TiSetClient(srctile, (ClientData)0);
+    TiSetClientINT(srctile, 0);
 
     /* Drop the first entry on the stack */
     sd = NewSD(cost, srctile, srctype, srcpnum);
@@ -883,9 +894,9 @@ donesrch:
 	    {
 		if (PlaneMaskHasPlane(pmask, p) && (p != pnum))
 		{
-		    tp = SelectDef->cd_planes[p]->pl_hint;
+		    tp = PlaneGetHint(SelectDef->cd_planes[p]);
 		    GOTOPOINT(tp, &tile->ti_ll);
-		    SelectDef->cd_planes[p]->pl_hint = tp;
+		    PlaneSetHint(SelectDef->cd_planes[p], tp);
 	    	    if (selShortProcessTile(tp, cost + 1, GEO_CENTER, lmask) == 0)
 		    {
 			sd = NewSD(cost + 1, tp, TiGetLeftType(tp), p);
@@ -983,7 +994,7 @@ SelectShort(char *lab1, char *lab2)
 	if (PlaneMaskHasPlane(pmask, destpnum))
 	{
 	    plane = SelectDef->cd_planes[destpnum];
-	    desttile = plane->pl_hint;
+	    desttile = PlaneGetHint(plane);
 	    GOTOPOINT(desttile, &destlab->lab_rect.r_ll)
 	    desttype = TiGetTopType(desttile);
 	    if (TTMaskHasType(&DBConnectTbl[destlab->lab_type], desttype)) break;
@@ -997,7 +1008,7 @@ SelectShort(char *lab1, char *lab2)
 	if (PlaneMaskHasPlane(pmask, srcpnum))
 	{
 	    plane = SelectDef->cd_planes[srcpnum];
-	    srctile = plane->pl_hint;
+	    srctile = PlaneGetHint(plane);
 	    GOTOPOINT(srctile, &srclab->lab_rect.r_ll)
 	    srctype = TiGetTopType(srctile);
 	    if (TTMaskHasType(&DBConnectTbl[srclab->lab_type], srctype)) break;
@@ -1009,7 +1020,7 @@ SelectShort(char *lab1, char *lab2)
     selShortFindForward(srctile, srctype, srcpnum, desttile/*, desttype*/);
 
     /* Now see if destination has been counted */
-    if (desttile->ti_client == (ClientData)CLIENTDEFAULT) return NULL;
+    if (TiGetClient(desttile) == CLIENTDEFAULT) return NULL;
 
     /* Now find the shortest path between source and destination */
     rlist = NULL;
